@@ -1,4 +1,3 @@
-import tkinter as tk
 import tkinter.simpledialog as sd
 
 import cv2
@@ -9,7 +8,6 @@ from matplotlib.figure import Figure
 from matplotlib.ticker import AutoMinorLocator
 from mpl_toolkits.axes_grid1.inset_locator import inset_axes, mark_inset
 from PIL import Image, ImageTk
-from win32api import GetSystemMetrics
 
 from ..resources.language import Text
 from .measurement_import import Measurement
@@ -23,6 +21,7 @@ class DoseFigureHandler:
         self.parent = parent
 
         self.norm = self.parent.norm.get()
+        self.calcparams = self.parent.calcparams.get()
         self.normvalue = "max"
         self.errorbars = True
         self.caxcorrection = False
@@ -35,7 +34,7 @@ class DoseFigureHandler:
         self.lang = self.parent.lang
         self.text = Text()
         self.style = plt.style.use("default")
-        self.colors = ["#009F6B", "#C40233", "#00008B", "#BCA136", "#654321"]
+        self.colors = self.parent.profile.get_attribute("colors")
         self.marker = "o--"
         self.markersize = self.parent.profile.get_attribute("markersize")
         self.linewidth = self.parent.profile.get_attribute("linewidth")
@@ -136,7 +135,6 @@ class DoseFigureHandler:
                         [x / plotdata.normpoint for x in plotdata.std_dev[self.half]]
                     ),
                 ]
-                + plotdata.params
             ]
 
         if self.plots[0].direction == "Z":
@@ -181,8 +179,7 @@ class DoseFigureHandler:
         """Scales an image to the width of the screen.
         """
 
-        scr_width = GetSystemMetrics(0)
-        width = int(scr_width)
+        width = self.parent.parent.winfo_screenwidth()
         scale_factor = image.shape[1] / width
         image = cv2.resize(
             image,
@@ -225,7 +222,13 @@ class DoseFigureHandler:
 
         """Adds the calculated parameters as descriptors
         """
+        temp = self.data
+        new_data = []
+        for index, data in enumerate(self.data):
+            params = self.plots[index].params()
+            new_data += [[data, params]]
 
+        self.data = new_data
         if self.plots[0].direction != "Z":
 
             if self.half == False:
@@ -249,8 +252,9 @@ class DoseFigureHandler:
 
         for index, plot_data in enumerate(self.data):
 
-            if len(plot_data) == 7:
-                Q, dQ, zmax = plot_data[4], plot_data[5], plot_data[6]
+            if len(plot_data[1]) == 3:
+
+                Q, dQ, zmax = plot_data[1][0], plot_data[1][1], plot_data[1][2]
                 textstr = "Q     = {} ± {}\n{} = {} mm".format(Q, dQ, "$z_{max}$", zmax)
                 space = 0
                 if dQ == 0:
@@ -269,6 +273,7 @@ class DoseFigureHandler:
                     bbox=self.props,
                     color=self.colors[index],
                 )
+
             else:
                 (
                     HWB,
@@ -281,15 +286,15 @@ class DoseFigureHandler:
                     Lintegral,
                     Rintegral,
                 ) = (
-                    plot_data[4],
-                    plot_data[5],
-                    plot_data[6],
-                    plot_data[7],
-                    plot_data[8],
-                    plot_data[9],
-                    plot_data[10],
-                    plot_data[11],
-                    plot_data[12],
+                    plot_data[1][0],
+                    plot_data[1][1],
+                    plot_data[1][2],
+                    plot_data[1][3],
+                    plot_data[1][4],
+                    plot_data[1][5],
+                    plot_data[1][6],
+                    plot_data[1][7],
+                    plot_data[1][8],
                 )
 
                 if self.caxcorrection == True:
@@ -326,7 +331,7 @@ class DoseFigureHandler:
                     horizontalalignment="center",
                     color=self.colors[index],
                 )
-
+        self.data = temp
         return
 
     def set_x_label(self):
@@ -353,8 +358,11 @@ class DoseFigureHandler:
         """
 
         for index, plot_data in enumerate(self.data):
-            if self.caxcorrection == True:
-                plot_data[0] = [x - plot_data[5] for x in plot_data[0]]
+
+            if self.calcparams == True:
+
+                if self.caxcorrection == True:
+                    plot_data[0] = [x - self.plots[index].cax for x in plot_data[0]]
 
             if self.errorbars == True:
                 try:
@@ -440,7 +448,8 @@ class DoseFigureHandler:
 
             loc = "lower left"
             if self.half == False and self.plots[0].direction != "Z":
-                loc = "lower center"
+                if self.ax.get_xlim()[1] > 30:
+                    loc = "lower center"
 
             self.axins = inset_axes(self.ax, "28%", "28%", loc=loc)
             yvalsat195 = []
@@ -522,7 +531,14 @@ class DoseFigureHandler:
         self.set_axis()
         self.set_x_label()
         self.create_plots_from_data()
-        self.add_descriptors()
+        if self.calcparams == True:
+            try:
+                self.add_descriptors()
+            except Exception as e:
+                self.parent.calcparams.set(False)
+                self.calcparams = False
+                sd.messagebox.showwarning("", self.text.calcfail[self.lang])
+
         self.add_legend()
         self.ax.set_aspect("auto")
         self.set_style()
