@@ -2,8 +2,9 @@ import os
 import tkinter as tk
 from tkinter import filedialog as fd
 from tkinter import simpledialog as sd
-from tkinter.font import NORMAL
+from tkinter.colorchooser import askcolor
 
+import pynput
 from PIL import Image, ImageTk
 
 from ..resources.language import Text
@@ -60,6 +61,9 @@ class MainApplication(tk.Frame):
         self.half = tk.BooleanVar()
         self.half.set(bool(self.profile.get_attribute("halfview")))
 
+        self.calcparams = tk.BooleanVar()
+        self.calcparams.set(False)
+
         self.fullscreen = tk.BooleanVar()
         self.fullscreen.set(bool(self.profile.get_attribute("fullscreen")))
 
@@ -254,12 +258,12 @@ class MainApplication(tk.Frame):
             label=Text().marker[self.lang], menu=self.markersizemenu
         )
 
-        self.normmenu.add_separator()
-        self.normmenu.add_checkbutton(
-            label=self.text.errorbars[self.lang],
-            command=self.show_errorbars,
-            variable=self.errorbars,
+        self.normmenu.add_command(
+            label=self.text.resetcolors[self.lang], command=self.reset_colors
         )
+
+        self.normmenu.add_separator()
+
         self.normalizemenu = tk.Menu(self.menubar, tearoff=False)
         self.normalizemenu.add_checkbutton(
             label=self.text.normalize[self.lang],
@@ -292,19 +296,32 @@ class MainApplication(tk.Frame):
         self.normmenu.add_cascade(
             label=self.text.normalization[self.lang], menu=self.normalizemenu
         )
-
+        self.normmenu.add_checkbutton(
+            label=self.text.errorbars[self.lang],
+            command=self.show_errorbars,
+            variable=self.errorbars,
+        )
         self.normmenu.add_checkbutton(
             label=self.text.zoom[self.lang], command=self.zoomgraph, variable=self.zoom,
         )
+
         self.normmenu.add_checkbutton(
             label=self.text.half[self.lang], command=self.halfgraph, variable=self.half,
         )
+        self.normmenu.add_separator()
+        self.normmenu.add_checkbutton(
+            label=self.text.calcparams[self.lang],
+            command=self.calculate_parameters,
+            variable=self.calcparams,
+        )
+
         self.normmenu.add_checkbutton(
             label=self.text.caxcorrection[self.lang],
             command=self.correct_caxdev,
             variable=self.caxcorrection,
         )
 
+        self.normmenu.entryconfig(10, state=tk.DISABLED)
         self.parent.config(menu=self.menubar)
 
         self.parent.title(self.text.window_title[self.lang])
@@ -372,7 +389,12 @@ class MainApplication(tk.Frame):
 
         plots = self.DoseFigureHandler.plots
         filenames = self.filenames
+        dark = self.dark.get()
         axlims = self.axlims.get()
+        calcparams = self.calcparams.get()
+        caxcorrection = self.caxcorrection.get()
+        normalize = self.norm.get()
+        errorbars = self.errorbars.get()
         self.pack_forget()
         self.parent.config(menu=None)
         self.profile.set_attribute("language", language)
@@ -380,7 +402,12 @@ class MainApplication(tk.Frame):
         if plots != []:
             self.filenames = filenames
             self.DoseFigureHandler.plots = plots
+            self.dark.set(dark)
             self.axlims.set(axlims)
+            self.calcparams.set(calcparams)
+            self.caxcorrection.set(caxcorrection)
+            self.norm.set(normalize)
+            self.errorbars.set(errorbars)
             self.show_preview()
 
         return
@@ -434,11 +461,12 @@ class MainApplication(tk.Frame):
         self.menubar.delete(3, 4)
         self.filenames = []
         self.canvas.itemconfig(self.image_on_canvas, image=None)
-        self.menuflag = str
         self.DoseFigureHandler.flush()
         self.DoseFigureHandler.plots = []
         self.saved = True
         self.menuflag = False
+        self.DoseFigureHandler.caxcorrection = False
+        self.caxcorrection.set(False)
         self.axlims.set(0)
 
         return
@@ -518,6 +546,28 @@ class MainApplication(tk.Frame):
 
         return
 
+    def calculate_parameters(self):
+
+        """Choose whether or not the displayed dose
+        profiles should be center-axis-corrected
+        """
+
+        self.DoseFigureHandler.calcparams = self.calcparams.get()
+
+        if self.calcparams.get() == True:
+            if self.direction != "Z":
+                self.normmenu.entryconfig(10, state=tk.NORMAL)
+        else:
+            self.normmenu.entryconfig(10, state=tk.DISABLED)
+            self.caxcorrection.set(False)
+
+        if self.filenames != []:
+            self.canvas.itemconfig(self.image_on_canvas, image=None)
+            self.DoseFigureHandler.flush()
+            self.show_preview()
+
+        return
+
     def remove_last_addition(self, event=None):
 
         """
@@ -636,20 +686,32 @@ class MainApplication(tk.Frame):
             self.show_preview()
         return
 
+    def reset_colors(self):
+        self.profile.set_attribute(
+            "colors", self.profile.get_attribute("default_colors")
+        )
+        self.DoseFigureHandler.colors = self.profile.get_attribute("default_colors")
+        self.show_preview()
+
     def show_preview(self):
 
         """
         Invokes DoseFigureHandler to create and display the graphs with the selected options
         """
         self.DoseFigureHandler.flush()
-        self.photoimage, menuflag = self.DoseFigureHandler.return_figure(self.filenames)
+        self.photoimage, self.direction = self.DoseFigureHandler.return_figure(
+            self.filenames
+        )
 
         self.canvas.place_forget()
         self.canvas = tk.Canvas(self)
         self.canvas.bind("<Configure>", self.handle_configure)
         self.canvas.bind("<Button-1>", self.check_click)
+        self.canvas.bind("<Button-3>", self.check_right_click)
         self.canvas.bind("<Motion>", self.check_hand)
         self.canvas.bind("<Double-Button-1>", self.new_zoom)
+        self.parent.bind("<Up>", lambda boolean: self.change_order(True))
+        self.parent.bind("<Down>", lambda boolean: self.change_order(False))
         self.canvas.place(relheight=1, relwidth=1, relx=0.5, rely=0.5, anchor=tk.CENTER)
 
         if len(self.DoseFigureHandler.plots) >= 2:
@@ -658,14 +720,11 @@ class MainApplication(tk.Frame):
         if len(self.DoseFigureHandler.plots) == 5:
             self.addmenu.entryconfig(0, state=tk.DISABLED)
             self.addmenu.entryconfig(1, state=tk.DISABLED)
-
-        if menuflag == "Z":
+        if self.direction == "Z":
             self.addmeasuremenu.entryconfig(1, state=tk.DISABLED)
-            self.normmenu.entryconfig(6, state=tk.DISABLED)
             self.normmenu.entryconfig(7, state=tk.DISABLED)
         else:
             self.addmeasuremenu.entryconfig(0, state=tk.DISABLED)
-            self.normmenu.entryconfig(6, state=tk.NORMAL)
             self.normmenu.entryconfig(7, state=tk.NORMAL)
             self.canvas.place_forget()
             self.canvas.place(
@@ -683,6 +742,9 @@ class MainApplication(tk.Frame):
         self.canvas.itemconfig(self.image_on_canvas, image=self.canvas.image)
 
         for i in range(len(self.DoseFigureHandler.plots)):
+            normdiff = 0
+            if self.norm.get() == True:
+                normdiff = 0.035
             factor = (self.canvas.image.width() / self.canvas.image.height()) / 2
             temp = self.canvas.create_rectangle(
                 (
@@ -696,9 +758,9 @@ class MainApplication(tk.Frame):
                     + 0.94633
                 )
                 * self.canvas.image.width(),
-                (0.023 + 0.042 * i) * self.canvas.image.height() * factor,
+                (0.023 + normdiff + 0.042 * i) * self.canvas.image.height() * factor,
                 0.988 * self.canvas.image.width(),
-                (0.065 + 0.042 * i) * self.canvas.image.height() * factor,
+                (0.065 + normdiff + 0.042 * i) * self.canvas.image.height() * factor,
                 fill="",
                 outline="",
             )
@@ -728,6 +790,67 @@ class MainApplication(tk.Frame):
             self.canvas.move(self.oval, delta_x, delta_y)
             self.show_preview()
 
+    def change_order(self, boolean):
+
+        if self.index != None:
+
+            x = self.parent.winfo_pointerx()
+            y = self.parent.winfo_pointery()
+
+            if boolean == True:
+
+                new_index = self.index - 1
+                dy = -0.044
+
+                if self.index == 0:
+                    new_index = len(self.rename_boxes) - 1
+                    dy = 0.044 * (len(self.rename_boxes) - 1)
+
+            else:
+                if self.index + 1 == len(self.rename_boxes):
+                    new_index = 0
+                    dy = -0.044 * (len(self.rename_boxes) - 1)
+
+                else:
+                    new_index = self.index + 1
+                    dy = 0.044
+            (
+                self.DoseFigureHandler.plots[self.index],
+                self.DoseFigureHandler.plots[new_index],
+            ) = (
+                self.DoseFigureHandler.plots[new_index],
+                self.DoseFigureHandler.plots[self.index],
+            )
+            (
+                self.DoseFigureHandler.colors[self.index],
+                self.DoseFigureHandler.colors[new_index],
+            ) = (
+                self.DoseFigureHandler.colors[new_index],
+                self.DoseFigureHandler.colors[self.index],
+            )
+            self.profile.set_attribute("colors", self.DoseFigureHandler.colors)
+
+            try:
+                (self.filenames[self.index], self.filenames[new_index],) = (
+                    self.filenames[new_index],
+                    self.filenames[self.index],
+                )
+            except IndexError:
+                pass
+
+            factor = (
+                1000 * self.parent.winfo_height() / self.parent.winfo_screenheight()
+            )
+
+            x = self.parent.winfo_pointerx()
+            y = int(self.parent.winfo_pointery())
+            y += dy * factor
+            pynput.mouse.Controller().position = (x, y)
+            self.index = new_index
+            self.show_preview()
+            self.canvas.config(cursor="hand1")
+            return
+
     def handle_configure(self, event):
 
         """
@@ -765,6 +888,9 @@ class MainApplication(tk.Frame):
             x = self.canvas.image.width()
             y = self.canvas.image.height()
             self.canvas.delete(temp[i])
+            normdiff = 0
+            if self.norm.get() == False:
+                normdiff = 0.035
             factor = (self.canvas.image.width() / self.canvas.image.height()) / 2
             self.rename_boxes += [
                 self.canvas.create_rectangle(
@@ -782,9 +908,9 @@ class MainApplication(tk.Frame):
                         + 0.94633
                     )
                     * x,
-                    (0.023 + 0.042 * i) * y * factor,
+                    (0.023 + normdiff + 0.042 * i) * y * factor,
                     0.988 * x,
-                    (0.065 + 0.042 * i) * y * factor,
+                    (0.065 + normdiff + 0.042 * i) * y * factor,
                     fill="",
                     outline="",
                     tags="rename",
@@ -831,6 +957,11 @@ class MainApplication(tk.Frame):
             else:
                 self.canvas.config(cursor="")
 
+            try:
+                self.index = hoverlist.index(True)
+            except Exception as e:
+                self.index = None
+
     def check_click(self, e):
 
         """Renames a plot when the associated box is clicked
@@ -848,3 +979,27 @@ class MainApplication(tk.Frame):
                     if newname != None:
                         self.DoseFigureHandler.plots[index].filename = newname
                         self.show_preview()
+
+    def check_right_click(self, e):
+
+        """Reassigns a color to a plot when the associated box is right-clicked
+        """
+
+        for index, box in enumerate(self.rename_boxes):
+            if e != None:
+                bbox = self.canvas.bbox(box)
+                if bbox != None:
+                    if (
+                        bbox[0] < e.x
+                        and bbox[2] > e.x
+                        and bbox[1] < e.y
+                        and bbox[3] > e.y
+                    ):
+                        newcolor = askcolor(color=self.DoseFigureHandler.colors[index])
+                        if newcolor != None:
+                            self.DoseFigureHandler.colors[index] = newcolor[1]
+                            self.profile.set_attribute(
+                                "colors", self.DoseFigureHandler.colors
+                            )
+                            self.show_preview()
+
