@@ -8,6 +8,11 @@ class Text:
 
         self.add = {"de": "Daten hinzufügen", "en": "Add Data"}
         self.axis = {"de": "Achse", "en": "Axis"}
+        self.calcfail = {
+            "de": "Parameter konnten nicht berechnen werden!",
+            "en": "Parameters could not be calculated!",
+        }
+        self.calcparams = {"de": "Parameter berechnen", "en": "Calculate parameters"}
         self.caxcorrection = {
             "de": "Zentralstrahlkorrektur",
             "en": "Center axis correction",
@@ -74,6 +79,7 @@ class Text:
         self.pdd = {"de": "Tiefendosiskurve", "en": "Depth dose"}
         self.ptw = {"de": "PTW tbaScan", "en": "PTW tbaScan"}
         self.revert = {"de": "Rückgängig", "en": "Undo"}
+        self.resetcolors = {"de": "Farbschema zurücksetzen", "en": "Reset colorscheme"}
         self.save = {"de": "Graph abspeichern", "en": "Save graph"}
         self.scanaxis = {
             "de": "Scanrichtung: [X = Ja | Y = Nein]",
